get file = 'hh.sav'.
select if (HH9 = 1).
compute hhweight = hhweight*HH11.
weight by hhweight.

* create variable that will provide title in final table.
compute treat = 1.
value label treat 1  "Water treatment method used in the household".
variable label treat "".

compute none = 0.
if (WS5 <> 1) none = 100.
variable label none "None".

compute boil = 0.
if (WS6A = "A") boil = 100.
variable label boil "Boil".

compute bleach = 0.
if (WS6B = "B") bleach = 100.
variable label bleach "Add bleach/chlorine".

compute wfilter = 0.
if (WS6D = "D") wfilter = 100.
variable label wfilter "Use water filter".

compute stand = 0.
if (WS6F = "F") stand = 100.
variable label stand "Let it stand and settle".

compute other = 0.
if (WS6X = "X" or WS6X = "C" or WS6X = "E") other = 100.
variable label other "Other".

compute dk = 0.
if (WS6Z = "Z") dk = 100.
variable label dk "Don't know".

compute allh = 0.
if (boil = 100 or bleach = 100 or wfilter = 100) allh = 100.
variable label allh "All drinking water sources: Appropriate water treatment method *".

compute total = 1.
value label total 1 "".
variable label total "Number of household members".

recode WS1 (11,12,13,21,31,41,51 = 1) (else = 2) into type.
do if (WS1 = 91).
recode WS2 (11,12,13,21,31,41,51 = 1) (else = 2) into type.
end if.
variable label type "".
value label type 1 "Improved sources" 2 "Unimproved sources".

recode HC1C (11 = 1) (12 = 2) (14, 15 = 3) (17=4) (99=9) (else = 5)
	into etnic.
variable label etnic "Ethnicity of household head".
value label etnic
  1 "Serbian"
  2 "Montenegrian"
  3 "Bosnian\Muslim"
  4 "Albanian"
  5 "Other"
  9 "Missing".

do if (type  = 1).
+ compute improved = 0.
+ if (boil = 100 or bleach = 100 or wfilter = 100) improved = 100.
+ variable label improved "Improved drinking water sources: Appropriate water treatment method".
+ compute itotal = 1.
+ value label itotal  1 "".
+ variable label itotal "Number of household members".
end if.

do if (type  = 2).
+ compute unimp = 0.
+ if (boil = 100 or bleach = 100 or wfilter = 100) unimp = 100.
+ variable label unimp "Unimproved drinking water sources: Approprate water treatment method".
+ compute utotal = 1.
+ value label utotal  1 "".
+ variable label utotal "Number of household members".
end if.

tables
  /format = zero
  /observation = none boil bleach wfilter stand other dk allh 
	  improved unimp
  /ftotal = tot1 "Total" 
  /table = HH7 + HH6 + helevel + etnic + wlthind5 + tot1 by treat > 
	  (none + boil + bleach + wfilter + stand + other + dk) + 
		allh + total + improved + itotal + unimp + utotal
  /statistics
    mean(none (f5.1) '')
    mean(boil (f5.1) '')
    mean(bleach (f5.1) '')
    mean(wfilter (f5.1) '')
    mean(stand (f5.1) '')
    mean(other (f5.1) '')
    mean(dk (f5.1) '')
    mean(allh (f5.1) '')
    count(total (f5.0) '')
    mean(improved (f5.1) '')
    count(itotal (f5.0) '')
    mean(unimp (f5.1) '')
    count(utotal (f5.0) '')
  /title
    "Table EN.2: Household water treatment"
		"Percentage distribution of household population according to drinking water "+
		"treatment method used in the household and percentage of household "+
		"members that applied an appropriate water treatment method, Montenegro, 2005"
  /caption
    "* MICS indicator 13".

new file.
